#include "Riostream.h"
#include "TDatime.h"
#include "TPolyMarker.h"
#include "TPolyLine.h"
#include "TLine.h"
#include "TCanvas.h"
#include "TGraph.h"
#include "TAxis.h"
#include "TH1.h"
#include "TH2.h"
#include "TLegend.h"  
#include "TFile.h"
#include "TTree.h"
#include "TStyle.h"
#include "TChain.h"
#include "TMarker.h"
#include "TROOT.h"
#include "TF1.h"
#include "TProfile.h"
#include "TCut.h" 
#include "TGraphErrors.h"

using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(1111);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);

  gStyle->SetOptStat(0);

}


void AnalyzeEdEThreshold()
{
  HallA_style();

// Runs during calibration period

  TCanvas *c1 = new TCanvas("c1","c1", 1200,600);

  const int NumPoints = 8;
  double RunNumbers[NumPoints] = {1530, 1531, 1532, 1533, 1534, 1535, 2156, 2161};  
  double EPlaneVoltageSettings[NumPoints] = {100, 150, 200, 300, 60, 40, 150, 500};
  double EPlaneVoltageSettingsErrors[NumPoints] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
  double EPlaneEnergyLosses[NumPoints] = {3.32, 6.02, 7.82, 11.42, 2.78, 1.52, 5.12, 18.98};  
  double EPlaneEnergyLossesErrors[NumPoints] = {0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5};

  TGraphErrors *gr1  = new TGraphErrors(NumPoints, EPlaneVoltageSettings, EPlaneEnergyLosses, EPlaneVoltageSettingsErrors, EPlaneEnergyLossesErrors);
  gr1->SetMarkerStyle(25);
  gr1->SetMarkerSize(1.);
  gr1->SetMarkerColor(kBlue);
  gr1->SetTitle("E-plane Threshold ");
  gr1->GetXaxis()->SetTitle("U [mV]");  
  gr1->GetYaxis()->SetTitle("Deposited Energy [MeV]");
  //gr1->GetXaxis()->SetRangeUser(2160, 3650);
  gr1->Draw("AP");
  gPad->SetGrid();

  TF1 *fE = new TF1("fE", "[0]*x",0,320);
  gr1->Fit("fE");


  double dEPlaneVoltageSettings[NumPoints] = {100, 150, 200, 300, 60, 40, 150, 200};
  double dEPlaneVoltageSettingsErrors[NumPoints] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};

  double dEPlaneEnergyLosses[NumPoints] = {1.46, 2.66, 3.68, 5.78, 0.68, 0.56, 2.4, 3.62};  
  double dEPlaneEnergyLossesErrors[NumPoints] = {0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3};

  TCanvas *c2 = new TCanvas("c2","c2", 1200,600);
  c2->cd();

  TGraphErrors *gr2  = new TGraphErrors(NumPoints, dEPlaneVoltageSettings, dEPlaneEnergyLosses, dEPlaneVoltageSettingsErrors, dEPlaneEnergyLossesErrors);
  gr2->SetMarkerStyle(21);
  gr2->SetMarkerSize(1.2);
  gr2->SetMarkerColor(kRed);
  gr2->SetTitle("dE-plane Threshold ");
  gr2->GetXaxis()->SetTitle("U [mV]");  
  gr2->GetYaxis()->SetTitle("Deposited Energy [MeV]");
  gr2->Draw("AP");
  gPad->SetGrid();

  TF1 *fdE = new TF1("fdE", "[0]*x",0,320);
  gr2->Fit("fdE");

  c2->Print("dEThresholdPlot.png");


// Production runs, after calibration was done

// Runs during calibration period

  c1->cd();

  const int NumPointsProd = 8;
  double RunNumbersProd[NumPointsProd] = {2164, 2163, 2162, 2245, 2270,2215, 2216,2244};  
  double EPlaneVoltageSettingsProd[NumPointsProd] = {400, 401, 500, 300, 301, 402, 403, 302};
  double EPlaneVoltageSettingsErrorsProd[NumPointsProd] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
  double EPlaneEnergyLossesProd[NumPointsProd] = {15.02, 15.02, 19.3, 10.88, 10.52, 14.48, 14.87, 10.52};  
  double EPlaneEnergyLossesErrorsProd[NumPointsProd] = {0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5};

  TGraphErrors *gr1Prod  = new TGraphErrors(NumPointsProd, EPlaneVoltageSettingsProd, EPlaneEnergyLossesProd, EPlaneVoltageSettingsErrorsProd, EPlaneEnergyLossesErrorsProd);
  gr1Prod->SetMarkerStyle(24);
  gr1Prod->SetMarkerSize(1.2);
  gr1Prod->SetMarkerColor(kGreen);
  //gr1->GetXaxis()->SetRangeUser(2160, 3650);
  gr1Prod->Draw("P");
  gPad->SetGrid();

  TLegend *leg1 = new TLegend(0.6, 0.2, 0.86, 0.35 );
  leg1->AddEntry(gr1, "Data from Calibration Period","p");
  leg1->AddEntry(gr1Prod, "Production Data ","p");
  leg1->Draw("same");

  
  c1->Print("EThresholdPlot.png");

  
  c2->cd();

  double dEPlaneVoltageSettingsProd[NumPointsProd] = {300, 301, 200, 100, 101, 302, 150, 151};
  double dEPlaneVoltageSettingsErrorsProd[NumPointsProd] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,0.0 };
  double dEPlaneEnergyLossesProd[NumPointsProd] = {5.6, 5.6, 3.68, 1.46, 1.16, 5.55, 2.36, 2.31};  
  double dEPlaneEnergyLossesErrorsProd[NumPointsProd] = {0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3, 0.3};

  TGraphErrors *gr2Prod  = new TGraphErrors(NumPointsProd, dEPlaneVoltageSettingsProd, dEPlaneEnergyLossesProd, dEPlaneVoltageSettingsErrorsProd, dEPlaneEnergyLossesErrorsProd);
  gr2Prod->SetMarkerStyle(20);
  gr2Prod->SetMarkerSize(1.2);
  gr2Prod->SetMarkerColor(kOrange);
  gr2Prod->Draw("P");
  gPad->SetGrid();

  TLegend *leg2 = new TLegend(0.6, 0.2, 0.86, 0.35 );
  leg2->AddEntry(gr2, "Data from Calibration Period","p");
  leg2->AddEntry(gr2Prod, "Production Data","p");
  leg2->Draw("same");

  c2->Print("dEThresholdPlot.png");




}
